@@ -18,12 +18,12 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: Bookmarks.py,v 1.8 2003/12/02 02:35:49 rshura Exp $
+# $Id: Bookmarks.py,v 1.8.2.2 2005/03/14 02:35:50 rshura Exp $
 
 "Handle bookmarks for the gramps interface"
 
 __author__ = "Donald N. Allingham"
-__version__ = "$Revision: 1.8 $"
+__version__ = "$Revision: 1.8.2.2 $"
 
 #-------------------------------------------------------------------------
 #
@@ -93,10 +93,10 @@ class Bookmarks :
         title = "%s - GRAMPS" % _("Edit Bookmarks")
         self.top = gtk.Dialog(title)
         self.top.set_default_size(400,350)
-        self.top.set_has_separator(gtk.FALSE)
+        self.top.set_has_separator(False)
         self.top.vbox.set_spacing(5)
         label = gtk.Label('<span size="larger" weight="bold">%s</span>' % _("Edit Bookmarks"))
-        label.set_use_markup(gtk.TRUE)
+        label.set_use_markup(True)
         self.top.vbox.pack_start(label,0,0,5)
         box = gtk.HBox()
         self.top.vbox.pack_start(box,1,1,5)
