@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: ChooseParents.py,v 1.27.2.6 2004/07/30 02:38:59 rshura Exp $
+# $Id: ChooseParents.py,v 1.27.2.7 2005/03/12 17:27:58 rshura Exp $
 
 """
 ChooseParents interface allows users to select the paretns of an
@@ -26,7 +26,7 @@ individual.
 """
 
 __author__ = "Donald N. Allingham"
-__version__ = "$Revision: 1.27.2.6 $"
+__version__ = "$Revision: 1.27.2.7 $"
 
 #-------------------------------------------------------------------------
 #
@@ -539,7 +539,7 @@ class ModifyParents:
             "on_parents_help_clicked"  : self.on_help_clicked,
             })
 
-        self.title.set_use_markup(gtk.TRUE)
+        self.title.set_use_markup(True)
 
         if self.family.getRelationship() == "Partners":
             self.mlabel.set_label('<b>%s</b>' % _("Parent"))
