@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: EditPerson.py,v 1.78.2.6 2004/10/31 04:17:41 dallingham Exp $
+# $Id: EditPerson.py,v 1.78.2.8 2005/03/14 02:35:50 rshura Exp $
 
 #-------------------------------------------------------------------------
 #
@@ -611,7 +611,7 @@ class EditPerson:
         t = self.etree.tree
         (x,y) = icon.get_size()
         mask = gtk.gdk.Pixmap(self.window.window,x,y,1)
-        mask.draw_rectangle(t.get_style().white_gc, gtk.TRUE, 0,0,x,y)
+        mask.draw_rectangle(t.get_style().white_gc, True, 0,0,x,y)
         t.drag_source_set_icon(t.get_colormap(),icon,mask)
 
     def url_drag_data_received(self,widget,context,x,y,sel_data,info,time):
@@ -1019,7 +1019,7 @@ class EditPerson:
         female = self.is_female.get_active()
         unknown = self.is_unknown.get_active()
         text = unicode(self.notes_buffer.get_text(self.notes_buffer.get_start_iter(),
-                                          self.notes_buffer.get_end_iter(),gtk.FALSE))
+                                          self.notes_buffer.get_end_iter(),False))
         format = self.preform.get_active()
         idval = unicode(self.gid.get_text())
 
@@ -1495,7 +1495,7 @@ class EditPerson:
             ErrorDialog(msg)
 
         text = unicode(self.notes_buffer.get_text(self.notes_buffer.get_start_iter(),
-                                          self.notes_buffer.get_end_iter(),gtk.FALSE))
+                                          self.notes_buffer.get_end_iter(),False))
 
         if text != self.person.getNote():
             self.person.setNote(text)
@@ -1636,7 +1636,7 @@ class EditPerson:
             self.lds_not_loaded = 0
             self.draw_lds()
         text = unicode(self.notes_buffer.get_text(self.notes_buffer.get_start_iter(),
-                            self.notes_buffer.get_end_iter(),gtk.FALSE))
+                            self.notes_buffer.get_end_iter(),False))
         if text:
             Utils.bold_label(self.notes_label)
         else:
@@ -1667,7 +1667,7 @@ class EditPerson:
         # initial values
         name = '<span size="larger" weight="bold">%s</span>' % GrampsCfg.nameof(self.person)
         self.get_widget("activepersonTitle").set_text(name)
-        self.get_widget("activepersonTitle").set_use_markup(gtk.TRUE)
+        self.get_widget("activepersonTitle").set_use_markup(True)
         self.suffix.set_text(self.pname.getSuffix())
         self.prefix.set_text(self.pname.getSurnamePrefix())
 
