@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: EditPlace.py,v 1.31.2.3 2004/09/01 15:10:11 rshura Exp $
+# $Id: EditPlace.py,v 1.31.2.4 2005/03/14 02:35:50 rshura Exp $
 
 #-------------------------------------------------------------------------
 #
@@ -290,7 +290,7 @@ class EditPlace:
     def on_place_apply_clicked(self):
 
         note = unicode(self.note_buffer.get_text(self.note_buffer.get_start_iter(),
-                                 self.note_buffer.get_end_iter(),gtk.FALSE))
+                                 self.note_buffer.get_end_iter(),False))
         format = self.preform.get_active()
 	mloc = self.place.get_main_location()
 
@@ -333,7 +333,7 @@ class EditPlace:
             self.ref_not_loaded = 0
             self.display_references()
         text = unicode(self.note_buffer.get_text(self.note_buffer.get_start_iter(),
-                                self.note_buffer.get_end_iter(),gtk.FALSE))
+                                self.note_buffer.get_end_iter(),False))
         if text:
             Utils.bold_label(self.notes_label)
         else:
