@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: EventEdit.py,v 1.32.2.5 2004/10/31 04:17:42 dallingham Exp $
+# $Id: EventEdit.py,v 1.32.2.6 2005/03/14 02:35:51 rshura Exp $
 
 #-------------------------------------------------------------------------
 #
@@ -261,7 +261,7 @@ class EventEditor:
         eplace_obj = self.get_place(self.place_field,1)
         buf = self.note_field.get_buffer()
 
-        enote = unicode(buf.get_text(buf.get_start_iter(),buf.get_end_iter(),gtk.FALSE))
+        enote = unicode(buf.get_text(buf.get_start_iter(),buf.get_end_iter(),False))
         eformat = self.preform.get_active()
         edesc = unicode(self.descr_field.get_text())
         epriv = self.priv.get_active()
@@ -328,7 +328,7 @@ class EventEditor:
 
     def on_switch_page(self,obj,a,page):
         buf = self.note_field.get_buffer()
-        text = unicode(buf.get_text(buf.get_start_iter(),buf.get_end_iter(),gtk.FALSE))
+        text = unicode(buf.get_text(buf.get_start_iter(),buf.get_end_iter(),False))
         if text:
             Utils.bold_label(self.notes_label)
         else:
