@@ -18,7 +18,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-# $Id: FamilyView.py,v 1.84 2004/02/04 04:42:06 dallingham Exp $
+# $Id: FamilyView.py,v 1.84.2.1 2004/07/11 03:54:30 dallingham Exp $
 
 #-------------------------------------------------------------------------
 #
@@ -1176,8 +1176,20 @@ class FamilyView:
                 return
 
             row = model.get_path(iter)
-            fam = person.getParentList()[row[0]]
-            person.removeAltFamily(fam[0])
+            fam = person.getParentList()[row[0]][0]
+            person.removeAltFamily(fam)
+            fam.removeChild(person)
+
+            if len(fam.getChildList()) == 0:
+                father = fam.getFather()
+                mother = fam.getMother()
+                if father == None and mother:
+                    mother.removeFamily(fam)
+                    self.parent.db.deleteFamily(fam)
+                elif mother == None and father:
+                    father.removeFamily(fam)
+                    self.parent.db.deleteFamily(fam)
+                    
         Utils.modified()
         self.load_family()
 
