@@ -1,7 +1,7 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2002-2003  Donald N. Allingham
+# Copyright (C) 2002-2005  Donald N. Allingham
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: GenericFilter.py,v 1.37.2.3 2004/09/13 18:09:06 twaugh Exp $
+# $Id: GenericFilter.py,v 1.37.2.4 2005/03/04 15:15:01 rshura Exp $
 
 """Generic Filtering Routines"""
 
@@ -1155,11 +1155,13 @@ class HasAttribute(Rule):
         return 'Has the personal attribute'
 
     def apply(self,db,p):
+        if not self.list[0]:
+            return 0
         for event in p.getAttributeList():
-            if self.list[0] and event.getType() != self.list[0]:
-                continue
-            ev = event.getValue().upper()
-            if self.list[1] and ev == self.list[1]:
+            name_match = event.getType() == self.list[0]
+            value_match = \
+                    event.getValue().upper().find(self.list[1].upper()) != -1
+            if name_match and value_match:
                 return 1
         return 0
 
@@ -1177,12 +1179,14 @@ class HasFamilyAttribute(Rule):
         return 'Has the family attribute'
 
     def apply(self,db,p):
+        if not self.list[0]:
+            return 0
         for f in p.getFamilyList():
             for event in f.getAttributeList():
-                if self.list[0] and event.getType() != self.list[0]:
-                    continue
-                ev = event.getValue().upper()
-                if self.list[1] and ev == self.list[1]:
+                name_match = event.getType() == self.list[0]
+                value_match = \
+                        event.getValue().upper().find(self.list[1].upper()) != -1
+                if name_match and value_match:
                     return 1
         return 0
 
