@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: GrampsCfg.py,v 1.46.2.2 2004/08/06 19:24:28 rshura Exp $
+# $Id: GrampsCfg.py,v 1.46.2.5 2005/03/14 02:35:52 rshura Exp $
 
 #-------------------------------------------------------------------------
 #
@@ -88,6 +88,7 @@ _date_format_list = [
     _("YYYY/MM/DD"),
     _("YYYY-MM-DD"),
     _("YYYY.MM.DD"),
+    _("Day Month Year"),
     ]
 
 _date_entry_list = [
@@ -786,7 +787,7 @@ class GrampsPreferences:
                     pairs = self.c[c][panel][frame]
                     fr = gtk.Frame(frame)
                     fr.show()
-                    box.pack_start(fr,gtk.FALSE,gtk.FALSE)
+                    box.pack_start(fr,False,False)
                     table = gtk.Table(len(pairs),2)
                     table.show()
                     fr.add(table)
@@ -1043,6 +1044,7 @@ def display_preferences_box(db):
 _view_str = "/apps/gramps/view"
 _toolbar_str = "/apps/gramps/toolbar-on"
 _screen_size_str = "/apps/gramps/screen-size-checked"
+_pop_plugin_status_str = "/apps/gramps/pop-plugin-status"
 
 def save_view(val):
     set_bool(_view_str, not val)
@@ -1069,3 +1071,9 @@ def get_screen_size_checked():
 
 def save_screen_size_checked(val):
     set_bool(_screen_size_str, val)
+
+def get_pop_plugin_status():
+    return not not client.get_bool(_pop_plugin_status_str)
+
+def save_pop_plugin_status(val):
+    set_bool(_pop_plugin_status_str, val)
