@@ -1,7 +1,7 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2000-2004  Donald N. Allingham
+# Copyright (C) 2000-2005  Donald N. Allingham
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: GrampsParser.py,v 1.23.2.3 2004/05/19 04:19:51 rshura Exp $
+# $Id: GrampsParser.py,v 1.23.2.4 2005/02/19 00:06:21 rshura Exp $
 
 import const
 import RelLib
@@ -27,7 +27,7 @@ import Date
 import string
 import Calendar
 import Utils
-import xml.parsers.expat
+from xml.parsers.expat import ParserCreate
     
 #-------------------------------------------------------------------------
 #
@@ -100,9 +100,9 @@ class GrampsParser:
         self.name = None
         self.tempDefault = None
         self.owner = RelLib.Researcher()
-	self.func_list = [None]*50
-	self.func_index = 0
-	self.func = None
+        self.func_list = [None]*50
+        self.func_index = 0
+        self.func = None
         self.witness_comment = ""
 
         self.func_map = {
@@ -191,7 +191,7 @@ class GrampsParser:
 
 
     def parse(self,file):
-        p = xml.parsers.expat.ParserCreate()
+        p = ParserCreate()
         p.StartElementHandler = self.startElement
         p.EndElementHandler = self.endElement
         p.CharacterDataHandler = self.characters
@@ -897,7 +897,7 @@ class GrampsParser:
         self.tlist = []
 
         try:
-	    f,self.func = self.func_map[tag]
+            f,self.func = self.func_map[tag]
             if f:
                 f(attrs)
         except KeyError:
