@@ -1,7 +1,7 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2000-2004  Donald N. Allingham
+# Copyright (C) 2000-2005  Donald N. Allingham
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: ImageSelect.py,v 1.54.2.5 2004/06/14 04:07:23 rshura Exp $
+# $Id: ImageSelect.py,v 1.54.2.10 2005/03/14 02:35:52 rshura Exp $
 
 #-------------------------------------------------------------------------
 #
@@ -26,8 +26,9 @@
 #
 #-------------------------------------------------------------------------
 import os
-import string
 import urlparse
+from gettext import gettext as _
+
 #-------------------------------------------------------------------------
 #
 # GTK/Gnome modules
@@ -56,7 +57,6 @@ import Sources
 import grampslib
 
 from QuestionDialog import ErrorDialog
-from gettext import gettext as _
 
 _IMAGEX = 140
 _IMAGEY = 150
@@ -311,7 +311,7 @@ class Gallery(ImageSelect):
                                       self.button, event)
                     
             self.in_event = 0
-            return gtk.TRUE
+            return True
 
         style = self.iconlist.get_style()
         
@@ -335,7 +335,7 @@ class Gallery(ImageSelect):
                 self.remember_y = event.y
                 self.button = event.button
                 self.in_event = 0
-                return gtk.TRUE
+                return True
 
             elif event.button == 3:
                 item = widget.get_item_at(event.x,event.y)
@@ -343,7 +343,7 @@ class Gallery(ImageSelect):
                     (i,t,b,self.photo,oid) = self.p_map[item]
                     self.show_popup(self.photo,event)
                 self.in_event = 0
-                return gtk.TRUE
+                return True
         elif event.type == gtk.gdk.BUTTON_RELEASE:
             self.button = 0
 #         elif event.type == gtk.gdk._2BUTTON_PRESS and event.button == 1:
@@ -352,7 +352,7 @@ class Gallery(ImageSelect):
 #                 (i,t,b,self.photo,oid) = self.p_map[item]
 #                 LocalMediaProperties(self.photo,self.path,self,self.parent_window)
 #             self.in_event = 0
-#             return gtk.TRUE
+#             return True
         elif event.type == gtk.gdk.MOTION_NOTIFY:
             if event.state & gtk.gdk.BUTTON1_MASK:
                 # Get the new position and move by the difference
@@ -363,13 +363,13 @@ class Gallery(ImageSelect):
                 self.remember_y = new_y
 
                 self.in_event = 0
-                return gtk.TRUE
+                return True
             
         if event.type == gtk.gdk.EXPOSE:
             self.load_images()
 
         self.in_event = 0
-        return gtk.FALSE
+        return False
 
     def savephoto(self, photo):
         """Save the photo in the dataobj object.  (Required function)"""
@@ -480,7 +480,7 @@ class Gallery(ImageSelect):
     def on_photolist_drag_data_received(self,w, context, x, y, data, info, time):
 	if data and data.format == 8:
             icon_index = self.get_index(w,x,y)
-            d = string.strip(string.replace(data.data,'\0',' '))
+            d = data.data.replace('\0',' ').strip()
             protocol,site,file, j,k,l = urlparse.urlparse(d)
             if protocol == "file":
                 name = file
@@ -785,7 +785,7 @@ class LocalMediaProperties:
         
     def on_notebook_switch_page(self,obj,junk,page):
         t = self.notes.get_buffer()
-        text = unicode(t.get_text(t.get_start_iter(),t.get_end_iter(),gtk.FALSE))
+        text = unicode(t.get_text(t.get_start_iter(),t.get_end_iter(),False))
         if text:
             Utils.bold_label(self.notes_label)
         else:
@@ -795,7 +795,7 @@ class LocalMediaProperties:
         priv = self.change_dialog.get_widget("private").get_active()
 
         t = self.notes.get_buffer()
-        text = unicode(t.get_text(t.get_start_iter(),t.get_end_iter(),gtk.FALSE))
+        text = unicode(t.get_text(t.get_start_iter(),t.get_end_iter(),False))
         note = self.photo.getNote()
         format = self.preform.get_active()
         if text != note or priv != self.photo.getPrivacy():
@@ -1017,11 +1017,23 @@ class GlobalMediaProperties:
                 if o.getReference() == self.object:
                     self.refmodel.add([_("Person"),p.getId(),GrampsCfg.nameof(p)])
                     any = 1
+            for e in p.getEventList() + [p.getBirth(), p.getDeath()]:
+                for o in e.getPhotoList():
+                    if o.getReference() == self.object:
+                        self.refmodel.add([_("Personal Event: %s") % e.getName(),
+                                                p.getId(),GrampsCfg.nameof(p)])
+                        any = 1
         for p in self.db.getFamilyMap().values():
             for o in p.getPhotoList():
                 if o.getReference() == self.object:
                     self.refmodel.add([_("Family"),p.getId(),Utils.family_name(p)])
                     any = 1
+            for e in p.getEventList():
+                for o in e.getPhotoList():
+                    if o.getReference() == self.object:
+                        self.refmodel.add([_("Family Event: %s") % e.getName(),
+                                                p.getId(),Utils.family_name(p)])
+                        any = 1
         for key in self.db.getSourceKeys():
             p = self.db.getSource(key)
             for o in p.getPhotoList():
@@ -1043,7 +1055,7 @@ class GlobalMediaProperties:
         if page == 3:
             self.display_refs()
         t = self.notes.get_buffer()
-        text = unicode(t.get_text(t.get_start_iter(),t.get_end_iter(),gtk.FALSE))
+        text = unicode(t.get_text(t.get_start_iter(),t.get_end_iter(),False))
         if text:
             Utils.bold_label(self.notes_label)
         else:
@@ -1051,7 +1063,7 @@ class GlobalMediaProperties:
             
     def on_apply_clicked(self, obj):
         t = self.notes.get_buffer()
-        text = unicode(t.get_text(t.get_start_iter(),t.get_end_iter(),gtk.FALSE))
+        text = unicode(t.get_text(t.get_start_iter(),t.get_end_iter(),False))
         desc = unicode(self.descr_window.get_text())
         note = self.object.getNote()
         format = self.preform.get_active()
@@ -1135,6 +1147,15 @@ class DeleteMediaQuery:
                     change = 1
             if change:
                 p.setPhotoList(nl)
+            for e in p.getEventList() + [p.getBirth(), p.getDeath()]:
+                change = 0
+                for photo in e.getPhotoList():
+                    if photo.getReference() != self.media:
+                        nl.append(photo)
+                    else:
+                        change = 1
+                if change:
+                    e.setPhotoList(nl)
 
         for p in self.db.getFamilyMap().values():
             nl = []
@@ -1146,6 +1167,15 @@ class DeleteMediaQuery:
                     change = 1
             if change:
                 p.setPhotoList(nl)
+            for e in p.getEventList():
+                change = 0
+                for photo in e.getPhotoList():
+                    if photo.getReference() != self.media:
+                        nl.append(photo)
+                    else:
+                        change = 1
+                if change:
+                    e.setPhotoList(nl)
 
         for key in self.db.getSourceKeys():
             p = self.db.getSource(key)
