@@ -18,10 +18,10 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: Marriage.py,v 1.38.2.3 2004/08/17 20:45:14 rshura Exp $
+# $Id: Marriage.py,v 1.38.2.5 2005/03/14 02:35:52 rshura Exp $
 
 import pickle
-import string
+from gettext import gettext as _
 
 #-------------------------------------------------------------------------
 #
@@ -40,6 +40,7 @@ import gnome
 #-------------------------------------------------------------------------
 
 import const
+import sort
 import GrampsCfg
 import Utils
 import AutoComp
@@ -50,7 +51,6 @@ import Date
 import Sources
 
 from QuestionDialog import QuestionDialog, WarningDialog, SaveDialog
-from gettext import gettext as _
 
 #-------------------------------------------------------------------------
 #
@@ -174,7 +174,8 @@ class Marriage:
         # set initial data
         self.gallery.load_images()
 
-        etitles = [(_('Event'),-1,100),(_('Date'),-1,125),(_('Place'),-1,150)]
+        etitles = [(_('Event'),0,100),(_('Date'),1,125),
+                    (_('Place'),3,150),('',-1,0)]
         atitles = [(_('Attribute'),-1,150),(_('Value'),-1,150)]
 
         self.etree = ListModel.ListModel(self.event_list, etitles,
@@ -415,7 +416,11 @@ class Marriage:
         self.etree.clear()
         self.emap = {}
         for data in self.elist:
-            iter = self.etree.add([const.display_fevent(data.getName()),data.getQuoteDate(),data.getPlaceName()],data)
+            iter = self.etree.add([const.display_fevent(data.getName()),
+                            data.getQuoteDate(),
+                            data.getPlaceName(),
+                            sort.build_sort_date(data.getDateObj())],
+                            data)
             self.emap[str(data)] = iter
         if self.elist:
             self.etree.select_row(0)
@@ -436,7 +441,7 @@ class Marriage:
             changed = 1
 
         text = unicode(self.notes_buffer.get_text(self.notes_buffer.get_start_iter(),
-                                  self.notes_buffer.get_end_iter(),gtk.FALSE))
+                                  self.notes_buffer.get_end_iter(),False))
         format = self.preform.get_active()
 
         if text != self.family.getNote():
@@ -534,7 +539,7 @@ class Marriage:
                 Utils.modified()
 
         text = unicode(self.notes_buffer.get_text(self.notes_buffer.get_start_iter(),
-                                  self.notes_buffer.get_end_iter(),gtk.FALSE))
+                                  self.notes_buffer.get_end_iter(),False))
         if text != self.family.getNote():
             self.family.setNote(text)
             Utils.modified()
@@ -708,7 +713,7 @@ class Marriage:
 
     def on_switch_page(self,obj,a,page):
         text = unicode(self.notes_buffer.get_text(self.notes_buffer.get_start_iter(),
-                                self.notes_buffer.get_end_iter(),gtk.FALSE))
+                                self.notes_buffer.get_end_iter(),False))
         if text:
             Utils.bold_label(self.notes_label)
         else:
@@ -729,7 +734,7 @@ class Marriage:
 
     def get_place(self,makenew=0):
         field = self.lds_place.entry
-        text = string.strip(unicode(field.get_text()))
+        text = unicode(field.get_text()).strip()
         if text:
             if self.pmap.has_key(text):
                 return self.db.getPlaceMap()[self.pmap[text]]
