@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: MergeData.py,v 1.10.2.5 2004/08/10 15:46:00 rshura Exp $
+# $Id: MergeData.py,v 1.10.2.7 2005/02/27 19:38:57 jsanchez Exp $
 
 #-------------------------------------------------------------------------
 #
@@ -239,8 +239,8 @@ class MergePeople:
         for xdata in self.p2.getAlternateNames():
             for data in list:
                 if data.are_equal(xdata):
-                    self.copy_note(xdata,data)
-                    self.copy_sources(xdata,data)
+                    self.copy_note(data,xdata)
+                    self.copy_sources(data,xdata)
                     break
             else:
                 self.p1.addAlternateName(xdata)
@@ -250,8 +250,8 @@ class MergePeople:
             for data in list:
                 if data.getType() == xdata.getType() and \
                    data.getValue() == xdata.getValue():
-                    self.copy_note(xdata,data)
-                    self.copy_sources(xdata,data)
+                    self.copy_note(data,xdata)
+                    self.copy_sources(data,xdata)
                     break
             else:
                 self.p1.addAttribute(xdata)
@@ -260,12 +260,22 @@ class MergePeople:
         for xdata in self.p2.getEventList():
             for data in list:
                 if data.are_equal(xdata):
-                    self.copy_note(xdata,data)
-                    self.copy_sources(xdata,data)
+                    self.copy_note(data,xdata)
+                    self.copy_sources(data,xdata)
                     break
             else:
                 self.p1.addEvent(xdata)
 
+        list = self.p1.getAddressList()[:]
+        for xdata in self.p2.getAddressList():
+            for data in list:
+                if data.are_equal(xdata):
+                    self.copy_note(data,xdata)
+                    self.copy_sources(data,xdata)
+                    break
+            else:
+                self.p1.addAddress(xdata)
+
         list = self.p1.getUrlList()[:]
         for xdata in self.p2.getUrlList():
             for data in list:
@@ -346,6 +356,8 @@ class MergePeople:
                 old_note = old_note + "\n\n"
             self.p1.setNote(old_note + self.p2.getNote())
 
+        self.copy_sources(self.p1,self.p2)
+
         try:
             self.db.removePerson(self.p2.getId())
             self.db.removePerson(self.p1.getId())
@@ -374,6 +386,62 @@ class MergePeople:
                 return myfamily
         return None
 
+    def merge_family_pair(self,tgt_family,src_family):
+        
+        # copy children from source to target
+
+        for child in src_family.getChildList():
+            if child not in tgt_family.getChildList():
+                parents = child.getParentList()
+                tgt_family.addChild(child)
+                if child.getMainParents() == src_family:
+                    child.setMainParents(tgt_family)
+                i = 0
+                for fam in parents[:]:
+                    if fam[0] == src_family:
+                        parents[i] = (tgt_family,fam[1],fam[2])
+                    i = i + 1
+        
+        # merge family events
+        
+        list = tgt_family.getEventList()[:]
+        for xdata in src_family.getEventList():
+            for data in list:
+                if data.are_equal(xdata):
+                    self.copy_note(data,xdata)
+                    self.copy_sources(data,xdata)
+                    break
+            else:
+                tgt_family.addEvent(xdata)
+
+        # merge family attributes
+
+        list = tgt_family.getAttributeList()[:]
+        for xdata in src_family.getAttributeList():
+            for data in list:
+                if data.getType() == xdata.getType() and \
+                   data.getValue() == xdata.getValue():
+                    self.copy_note(data,xdata)
+                    self.copy_sources(data,xdata)
+                    break
+            else:
+                tgt_family.addAttribute(xdata)
+
+        # merge family notes
+        
+        if src_family.getNote() != "":
+            old_note = tgt_family.getNote()
+            if old_note:
+                old_note = old_note + "\n\n"
+            tgt_family.setNote(old_note + src_family.getNote())
+
+        # merge family top-level sources
+        self.copy_sources(tgt_family, src_family)
+
+        # merge multimedia objects
+        for photo in src_family.getPhotoList():
+            tgt_family.addPhoto(photo)
+
     def merge_families(self):
         
         family_num = 0
@@ -404,20 +472,8 @@ class MergePeople:
                    src_family in tgt_family.getMother().getFamilyList():
                     tgt_family.getMother().removeFamily(src_family)
 
-                # copy children from source to target
-
-                for child in src_family.getChildList():
-                    if child not in tgt_family.getChildList():
-                        parents = child.getParentList()
-                        tgt_family.addChild(child)
-                        if child.getMainParents() == src_family:
-                            child.setMainParents(tgt_family)
-                        i = 0
-                        for fam in parents[:]:
-                            if fam[0] == src_family:
-                                parents[i] = (tgt_family,fam[1],fam[2])
-                            i = i + 1
-                        
+                self.merge_family_pair(tgt_family,src_family)
+                      
                 # delete the old source family
                 del self.db.getFamilyMap()[src_family.getId()]
 
@@ -435,21 +491,7 @@ class MergePeople:
                 # transfer child to new family, alter children to
                 # point to the correct family
                 
-                for child in src_family.getChildList():
-                    if child not in tgt_family.getChildList():
-                        parents = child.getParentList()
-                        tgt_family.addChild(child)
-                        if child.getMainParents() == src_family:
-                            child.setMainParents(tgt_family)
-                        i = 0
-                        for fam in parents[:]:
-                            if fam[0] == src_family:
-                                parents[i] = (tgt_family,fam[1],fam[2])
-                            i = i + 1
-
-                # add family events from the old to the new
-                for event in src_family.getEventList():
-                    tgt_family.addEvent(event)
+                self.merge_family_pair(tgt_family,src_family)
 
                 # change parents of the family to point to the new
                 # family
