@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: NameEdit.py,v 1.20.2.1 2004/10/07 15:04:21 dallingham Exp $
+# $Id: NameEdit.py,v 1.20.2.2 2005/03/14 02:35:52 rshura Exp $
 
 #-------------------------------------------------------------------------
 #
@@ -140,7 +140,7 @@ class NameEditor:
         prefix = unicode(self.prefix_field.get_text())
         suffix = unicode(self.suffix_field.get_text())
         note = unicode(self.note_buffer.get_text(self.note_buffer.get_start_iter(),
-                                 self.note_buffer.get_end_iter(),gtk.FALSE))
+                                 self.note_buffer.get_end_iter(),False))
         format = self.preform.get_active()
         priv = self.priv.get_active()
 
@@ -203,7 +203,7 @@ class NameEditor:
         
     def on_switch_page(self,obj,a,page):
         text = unicode(self.note_buffer.get_text(self.note_buffer.get_start_iter(),
-                                self.note_buffer.get_end_iter(),gtk.FALSE))
+                                self.note_buffer.get_end_iter(),False))
         if text:
             Utils.bold_label(self.notes_label)
         else:
