@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: PedView.py,v 1.28.2.1 2004/04/10 14:24:20 dallingham Exp $
+# $Id: PedView.py,v 1.28.2.2 2005/03/12 17:27:59 rshura Exp $
 
 #-------------------------------------------------------------------------
 #
@@ -356,7 +356,7 @@ class PedigreeView:
                         label = gtk.Label('<b><i>%s</i></b>' % cname)
                     else:
                         label = gtk.Label(cname)
-                    label.set_use_markup(gtk.TRUE)
+                    label.set_use_markup(True)
                     label.show()
                     label.set_alignment(0,0)
                     menuitem.add(label)
