@@ -1,7 +1,7 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2000-2004  Donald N. Allingham
+# Copyright (C) 2000-2005  Donald N. Allingham
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: PeopleStore.py,v 1.14.2.1 2004/08/17 20:45:14 rshura Exp $
+# $Id: PeopleStore.py,v 1.14.2.3 2005/03/12 17:27:59 rshura Exp $
  
 #-------------------------------------------------------------------------
 #
@@ -67,7 +67,7 @@ class PeopleStore:
         self.tree.connect('row-expanded',self.on_row_expanded)
         self.mylist = [TYPE_STRING]*ncols + [TYPE_INT]
 
-        self.tree.set_rules_hint(gtk.TRUE)
+        self.tree.set_rules_hint(True)
         self.model = None
         self.tree_roots = {}
         self.tree_open = {}
@@ -86,8 +86,8 @@ class PeopleStore:
             if name[0] != '':
                 column = gtk.TreeViewColumn(name[0],renderer,text=cnum)
                 column.set_min_width(name[2])
-                column.set_resizable(gtk.TRUE)
-                column.set_clickable(gtk.TRUE)
+                column.set_resizable(True)
+                column.set_clickable(True)
                 column.set_sort_column_id(name[1])
 
                 cnum +=  1
@@ -248,7 +248,7 @@ class PeopleStore:
         self.fill_row(name,iter)
 
     def expand_row(self,name,iter=None):
-        path = self.model.get_path(self.tree_roots[name])
+        path = self.model.get_path(self.tree_roots[unicode(name)])
         self.parent.parent.status_text(_('Updating display...'))
         self.tree.expand_row(path,1)
         self.parent.parent.modify_statusbar()
@@ -267,7 +267,7 @@ class PeopleStore:
                 self.model.set(new_iter,0,d[0],1,d[1],2,d[2],3,d[3],4,d[4],
                                5,d[5],6,d[6],7,d[7])
                 self.parent.id2col[d[1]] = (self,new_iter)
-	self.expand_row (name, iter)
+        self.expand_row (name, iter)
 
     def add(self,data,select=0):
         self.count = self.count + 1
@@ -324,4 +324,4 @@ class PeopleStore:
         model,iter = self.selection.get_selected()
         if iter:
             path = model.get_path(iter)
-            self.tree.scroll_to_cell(path,None,gtk.TRUE,0.5,0.5)
+            self.tree.scroll_to_cell(path,None,True,0.5,0.5)
