@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: Plugins.py,v 1.35.2.1 2004/02/14 19:33:40 rshura Exp $
+# $Id: Plugins.py,v 1.35.2.4 2005/03/12 17:28:00 rshura Exp $
 
 """
 The core of the GRAMPS plugin system. This module provides tasks to load
@@ -36,6 +36,7 @@ filters, importer, exporters, and document generators.
 import gobject
 import gtk
 import gtk.glade
+import gnome
 
 #-------------------------------------------------------------------------
 #
@@ -72,7 +73,6 @@ _tools   = []
 _imports = []
 _exports = []
 _success = []
-_failed  = []
 _expect  = []
 _attempt = []
 _loaddir = []
@@ -81,7 +81,7 @@ _bookdoc = []
 _drawdoc = []
 _failmsg = []
 _bkitems = []
-
+_status_up = None
 #-------------------------------------------------------------------------
 #
 # Default relationship calculator
@@ -165,7 +165,7 @@ class PluginDialog:
             self.apply_button.set_label(button_label)
         else:
             self.apply_button.set_label(_("_Apply"))
-        self.apply_button.set_use_underline(gtk.TRUE)
+        self.apply_button.set_use_underline(True)
         if tool_tip:
             try:
                 tt = gtk.gtk_tooltips_data_get(self.apply_button)
@@ -278,7 +278,7 @@ class ReportPlugins(PluginDialog):
         reports. This is used to build the selection tree on the left
         hand side of the dailog box."""
         PluginDialog.__init__(self,db,active,_reports,_("Report Selection"),
-			_("Select a report from those available on the left."),
+                        _("Select a report from those available on the left."),
                         _("_Generate"), _("Generate selected report"))
 
 #-------------------------------------------------------------------------
@@ -296,7 +296,7 @@ class ToolPlugins(PluginDialog):
         hand side of the dailog box."""
 
         PluginDialog.__init__(self,db,active,_tools,_("Tool Selection"),
-			_("Select a tool from those available on the left."),
+                        _("Select a tool from those available on the left."),
                         _("_Run"), _("Run selected tool"))
         self.update = update
 
@@ -309,14 +309,24 @@ class PluginStatus:
     """Displays a dialog showing the status of loaded plugins"""
     
     def __init__(self):
+        global _status_up
+        if _status_up:
+            _status_up.close(None)
+        _status_up = self
         import cStringIO
         
         self.glade = gtk.glade.XML(const.pluginsFile,"plugstat","gramps")
         self.top = self.glade.get_widget("plugstat")
         self.top.set_title("%s - GRAMPS" % _('Plugin status'))
         window = self.glade.get_widget("text")
+        self.pop_button = self.glade.get_widget("pop_button")
+        if GrampsCfg.get_pop_plugin_status():
+            self.pop_button.set_active(1)
+        else:
+            self.pop_button.set_active(0)
         self.glade.signal_autoconnect({
-            'on_close_clicked' : self.close
+            'on_close_clicked' : self.close,
+            'on_help_clicked' : self.help,
             })
 
         info = cStringIO.StringIO()
@@ -327,21 +337,27 @@ class PluginStatus:
             info.write(_("The following modules could not be loaded:"))
             info.write("\n\n")
             
-            for (file,msg) in _expect:
-                info.write("%s: %s\n\n" % (file,msg))
+            for (filename,msg) in _expect:
+                info.write("%s: %s\n\n" % (filename,msg))
 
-            for (file,msgs) in _failmsg:
+            for (filename,msgs) in _failmsg:
                 error = str(msgs[0])
                 if error[0:11] == "exceptions.":
                     error = error[11:]
-                info.write("%s: %s\n" % (file,error) )
+                info.write("%s: %s\n" % (filename,error) )
                 traceback.print_exception(msgs[0],msgs[1],msgs[2],None,info)
                 info.write('\n')
             info.seek(0)
             window.get_buffer().set_text(info.read())
 
     def close(self,obj):
+        GrampsCfg.save_pop_plugin_status(self.pop_button.get_active())
         self.top.destroy()
+        _status_up = None
+
+    def help(self,obj):
+        """Display the GRAMPS manual"""
+        gnome.help_display('gramps-manual','gramps-getting-started')
         
 #-------------------------------------------------------------------------
 #
@@ -355,7 +371,7 @@ def load_plugins(direct):
     responsible for registering itself in the correct manner. No attempt
     is done in this routine to register the tasks."""
     
-    global _success,_failed,_attempt,_loaddir
+    global _success,_attempt,_loaddir,_failmsg
     
     # if the directory does not exist, do nothing
     if not os.path.isdir(direct):
@@ -365,7 +381,7 @@ def load_plugins(direct):
     # list for use on reloading
 
     if direct not in _loaddir:
-	_loaddir.append(direct)
+        _loaddir.append(direct)
 
     # add the directory to the python search path
     sys.path.append(direct)
@@ -377,20 +393,23 @@ def load_plugins(direct):
     # add it to the _success list. If it fails, add it to the _failure
     # list
     
-    for file in os.listdir(direct):
-        name = os.path.split(file)
+    for filename in os.listdir(direct):
+        name = os.path.split(filename)
         match = pymod.match(name[1])
         if not match:
             continue
-	_attempt.append(file)
+        _attempt.append(filename)
         plugin = match.groups()[0]
         try: 
             a = __import__(plugin)
             _success.append(a)
         except Errors.PluginError, msg:
-            _expect.append((file,str(msg)))
+            _expect.append((filename,str(msg)))
         except:
-            _failmsg.append((file,sys.exc_info()))
+            _failmsg.append((filename,sys.exc_info()))
+    
+    if GrampsCfg.get_pop_plugin_status() and len(_expect)+len(_failmsg):
+        PluginStatus()
 
 #-------------------------------------------------------------------------
 #
@@ -403,40 +422,60 @@ def reload_plugins(obj):
     
     pymod = compile(r"^(.*)\.py$")
 
-    # attempt to reload all plugins that have succeeded
-    # in the past
+    global _success,_attempt,_loaddir,_failmsg
+
+    oldfailmsg = _failmsg[:]
+    _failmsg = []
+
+    # attempt to reload all plugins that have succeeded in the past
     for plugin in _success:
+        filename = os.path.basename(plugin.__file__)
+        filename = filename.replace('pyc','py')
+        filename = filename.replace('pyo','py')
         try: 
             reload(plugin)
         except:
-            _failmsg.append((plugin,sys.exc_info()))
-            
+            _success.remove(plugin)
+            _failmsg.append((filename,sys.exc_info()))
+
     # attempt to load the plugins that have failed in the past
-    
-    for plugin in _failed:
+    for (filename,message) in oldfailmsg:
+        name = os.path.split(filename)
+        match = pymod.match(name[1])
+        if not match:
+            continue
+        _attempt.append(filename)
+        plugin = match.groups()[0]
         try: 
-            __import__(plugin)
-            del _failmsg[plugin]
+            # For some strange reason second importing of a failed plugin
+            # results in success. Then reload reveals the actual error.
+            # Looks like a bug in Python.
+            a = __import__(plugin)
+            reload(a)
+            _success.append(a)
         except:
-            _failmsg.append((plugin,sys.exc_info()))
+            _failmsg.append((filename,sys.exc_info()))
 
     # attempt to load any new files found
-    for dir in _loaddir:
- 	for file in os.listdir(dir):
-            name = os.path.split(file)
-	    match = pymod.match(name[1])
+    for dirname in _loaddir:
+        for filename in os.listdir(dirname):
+            name = os.path.split(filename)
+            match = pymod.match(name[1])
             if not match:
                 continue
-            if file in _attempt:
-                return
-            _attempt.append(file)
+            if filename in _attempt:
+                continue
+            _attempt.append(filename)
             plugin = match.groups()[0]
             try: 
                 a = __import__(plugin)
                 if a not in _success:
                     _success.append(a)
             except:
-                _failmsg.append((file,sys.exc_info()))
+                _failmsg.append((filename,sys.exc_info()))
+
+    if GrampsCfg.get_pop_plugin_status() and len(_failmsg):
+        PluginStatus()
 
 #-------------------------------------------------------------------------
 #
