@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: StartupDialog.py,v 1.17.2.3 2004/10/26 02:26:18 dallingham Exp $
+# $Id: StartupDialog.py,v 1.17.2.5 2005/03/12 17:28:00 rshura Exp $
 
 import const
 import gtk.glade
@@ -70,8 +70,12 @@ class StartupDialog:
         d.add(self.build_page_last())
 
         d.connect('cancel',self.close)
-        self.w.connect("destroy_event", gtk.mainquit)
-        self.w.connect("delete_event", gtk.mainquit)
+        if gtk.pygtk_version > (2,2,0):
+            self.w.connect("destroy_event", gtk.main_quit)
+            self.w.connect("delete_event", gtk.main_quit)
+        else:
+            self.w.connect("destroy_event", gtk.mainquit)
+            self.w.connect("delete_event", gtk.mainquit)
         
         self.w.show_all()
 
@@ -153,7 +157,7 @@ class StartupDialog:
         label = gtk.Label(_('In order to create valid GEDCOM files, the following information '
                             'needs to be entered. If you do not plan to generate GEDCOM files, '
                             'you may leave this empty.'))
-        label.set_line_wrap(gtk.TRUE)
+        label.set_line_wrap(True)
         
         box.pack_start(label)
         
