@@ -3,7 +3,7 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2000-2004  Donald N. Allingham
+# Copyright (C) 2000-2005  Donald N. Allingham
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: const.py.in,v 1.43.2.1 2004/02/13 22:43:36 dallingham Exp $
+# $Id: const.py.in,v 1.43.2.3 2005/03/08 17:41:13 rshura Exp $
 
 #-------------------------------------------------------------------------
 #
@@ -108,7 +108,7 @@ dnd_images     = 1
 #
 #-------------------------------------------------------------------------
 progName     = "GRAMPS"
-version      = "1.0.8-1"
+version      = "1.0.11-1"
 copyright    = unicode(" 2001-2004 Donald N. Allingham","iso-8859-1")
 comments     = _("GRAMPS (Genealogical Research and Analysis "
                  "Management Programming System) is a personal "
@@ -354,6 +354,7 @@ personalConstantAttributes = {
     "Description"           : "DSCR",
     "Identification Number" : "IDNO",
     "National Origin"       : "NATI",
+    "Number of Children"    : "NCHI",
     "Social Security Number": "SSN"
     }
 
@@ -368,6 +369,7 @@ personal_attributes = TransTable({
     "Description"           : _("Description"),
     "Identification Number" : _("Identification Number"),
     "National Origin"       : _("National Origin"),
+    "Number of Children"    : _("Number of Children"),
     "Social Security Number": _("Social Security Number")
     })
 
@@ -412,7 +414,7 @@ def save_attr(st):
         return personal_attributes.find_key(st)
     if family_attributes.has_value(st):
         return family_attributes.find_key(st)
-    return _(st)
+    return st
 
 #-------------------------------------------------------------------------
 #
