@@ -24,7 +24,7 @@
 # Written by Billy C. Earney, 2003-2004
 # Modified by Alex Roitman, 2004
 
-# $Id: LPRDoc.py,v 1.26.2.3 2004/03/22 16:25:19 rshura Exp $
+# $Id: LPRDoc.py,v 1.26.2.4 2004/08/12 02:02:38 rshura Exp $
 
 """LPR document generator"""
 
@@ -551,6 +551,9 @@ class LPRDoc(BaseDoc.BaseDoc):
     #
     #------------------------------------------------------------------------
 
+    def string_width(self,fontstyle,text):
+        return get_text_width(text,fontstyle)
+
     def line_break(self):
         "Forces a line break within a paragraph."
         # Add previously held text to the paragraph, 
