@@ -348,6 +348,8 @@ class PSDrawDoc(BaseDoc.BaseDoc):
 	para_name = box_style.get_paragraph_style()
 	p = self.style_list[para_name]
         (junk,fdef) = self.encode_text(p,text)
+
+        print style, box_style.get_line_width()
         
         bh = box_style.get_height()
         bw = box_style.get_width()
@@ -371,12 +373,13 @@ class PSDrawDoc(BaseDoc.BaseDoc):
         self.f.write('closepath\n')
         self.f.write('1 setgray\n')
         self.f.write('fill\n')
-        self.f.write('newpath\n')
-        self.f.write('%f cm %f cm moveto\n' % self.translate(x,y))
-        self.f.write('0 -%f cm rlineto\n' % bh)
-        self.f.write('%f cm 0 rlineto\n' % bw)
-        self.f.write('0 %f cm rlineto\n' % bh)
-        self.f.write('closepath\n')
+        if box_style.get_line_width():
+            self.f.write('newpath\n')
+            self.f.write('%f cm %f cm moveto\n' % self.translate(x,y))
+            self.f.write('0 -%f cm rlineto\n' % bh)
+            self.f.write('%f cm 0 rlineto\n' % bw)
+            self.f.write('0 %f cm rlineto\n' % bh)
+            self.f.write('closepath\n')
         self.f.write('%.4f setlinewidth\n' % box_style.get_line_width())
         self.f.write('%.4f %.4f %.4f setrgbcolor stroke\n' % rgb_color(box_style.get_color()))
 	if text != "":
