@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: SvgDrawDoc.py,v 1.14.2.2 2004/09/14 12:57:52 twaugh Exp $
+# $Id: SvgDrawDoc.py,v 1.14.2.3 2005/01/20 00:12:07 dallingham Exp $
 
 #-------------------------------------------------------------------------
 #
@@ -182,18 +182,20 @@ class SvgDrawDoc(BaseDoc.BaseDoc):
         
         bh = box_style.get_height()
         bw = box_style.get_width()
-        self.f.write('<rect ')
-        self.f.write('x="%4.2fcm" ' % (x+0.15))
-        self.f.write('y="%4.2fcm" ' % (y+0.15))
-        self.f.write('width="%4.2fcm" ' % bw)
-        self.f.write('height="%4.2fcm" ' % bh)
-        self.f.write('style="fill:#808080; stroke:#808080; stroke-width:1;"/>\n')
+        if box_style.get_shadow():
+            self.f.write('<rect ')
+            self.f.write('x="%4.2fcm" ' % (x+0.15))
+            self.f.write('y="%4.2fcm" ' % (y+0.15))
+            self.f.write('width="%4.2fcm" ' % bw)
+            self.f.write('height="%4.2fcm" ' % bh)
+            self.f.write('style="fill:#808080; stroke:#808080; stroke-width:1;"/>\n')
         self.f.write('<rect ')
         self.f.write('x="%4.2fcm" ' % x)
         self.f.write('y="%4.2fcm" ' % y)
         self.f.write('width="%4.2fcm" ' % bw)
         self.f.write('height="%4.2fcm" ' % bh)
-        self.f.write('style="fill:#%02x%02x%02x; stroke:#000000; stroke-width:1;"/>\n' % box_style.get_fill_color())
+        self.f.write('style="fill:#%02x%02x%02x; stroke:#000000; ' % box_style.get_fill_color())
+        self.f.write('stroke-width:%f;"/>\n' % box_style.get_line_width())
         if text != "":
             font = p.get_font()
             font_size = font.get_size()
