@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: gramps_main.py,v 1.180.2.10 2004/08/16 21:24:03 rshura Exp $
+# $Id: gramps_main.py,v 1.180.2.13 2005/03/14 23:34:40 dallingham Exp $
 
 #-------------------------------------------------------------------------
 #
@@ -79,7 +79,7 @@ import GrampsXML
 # Constants
 #
 #-------------------------------------------------------------------------
-_HOMEPAGE  = "http://gramps.sourceforge.net"
+_HOMEPAGE  = "http://gramps-project.org"
 _MAILLIST  = "http://sourceforge.net/mail/?group_id=25770"
 _BUGREPORT = "http://sourceforge.net/tracker/?group_id=25770&atid=385137"
 
@@ -1050,7 +1050,7 @@ class Gramps:
         self.full_update()
 
     def read_file(self,filename):
-        self.topWindow.set_resizable(gtk.FALSE)
+        self.topWindow.set_resizable(False)
         filename = os.path.normpath(os.path.abspath(filename))
 
         base = os.path.basename(filename)
@@ -1075,7 +1075,7 @@ class Gramps:
             self.topWindow.set_title("%s - GRAMPS" % name)
         else:
             GrampsCfg.save_last_file("")
-        self.topWindow.set_resizable(gtk.TRUE)
+        self.topWindow.set_resizable(True)
         self.people_view.apply_filter()
         self.goto_active_person(1)
         
