@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: AncestorChart2.py,v 1.10.2.6 2004/08/12 02:02:38 rshura Exp $
+# $Id: AncestorChart2.py,v 1.10.2.7 2005/03/12 17:28:00 rshura Exp $
 
 "Graphical Reports/Ancestor Chart"
 
@@ -643,7 +643,7 @@ class AncestorChartBareDialog(Report.BareReportDialog):
             new_name = new_person.getPrimaryName().getRegularName()
             if new_name:
                 self.person_label.set_text( "<i>%s</i>" % new_name )
-                self.person_label.set_use_markup(gtk.TRUE)
+                self.person_label.set_use_markup(True)
 
     def on_cancel(self, obj):
         pass
