@@ -1,7 +1,7 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2000-2003  Donald N. Allingham
+# Copyright (C) 2000-2004  Donald N. Allingham
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,6 +18,8 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
+# $Id: AncestorReport.py,v 1.20.2.2 2004/08/17 18:05:18 rshura Exp $
+
 "Text Reports/Ahnentafel Report"
 
 #------------------------------------------------------------------------
@@ -25,8 +27,8 @@
 # python modules
 #
 #------------------------------------------------------------------------
-import os
 import string
+from gettext import gettext as _
 
 #------------------------------------------------------------------------
 #
@@ -38,7 +40,6 @@ import BaseDoc
 import RelLib
 import Errors
 from QuestionDialog import ErrorDialog
-from gettext import gettext as _
 
 #------------------------------------------------------------------------
 #
@@ -206,7 +207,7 @@ class AncestorReport(Report.Report):
                                         t = _(", and was buried in the year %s.") % \
                                             date.getDate()
                             else:
-                                t = _(" and was buried in %s." % place)
+                                t = _(" and was buried in %s.") % place
                         self.doc.write_text(t)
                     else:
                         self.doc.write_text(".")
