@@ -1,7 +1,7 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2003-2004  Donald N. Allingham
+# Copyright (C) 2003-2005  Donald N. Allingham
 # Copyright (C) 2003  Tim Waugh
 #
 # This program is free software; you can redistribute it and/or modify
@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: Ancestors.py,v 1.40.2.9 2004/10/27 18:38:45 eerot Exp $
+# $Id: Ancestors.py,v 1.40.2.14 2005/03/12 17:28:01 rshura Exp $
 
 #------------------------------------------------------------------------
 #
@@ -49,7 +49,6 @@ import Plugins
 import Calendar
 from QuestionDialog import ErrorDialog
 
-
 #------------------------------------------------------------------------
 #
 # ComprehensiveAncestorsReport
@@ -232,6 +231,7 @@ class ComprehensiveAncestorsReport (Report.Report):
             for family in pfamilies:
                 people.extend (self.family (family, already_described))
 
+            paternal_known = (len (people) > 0)
             if thisgen > 2 and len (mfamilies):
                 for self.gp in [mfamilies[0].getFather (),
                                 mfamilies[0].getMother ()]:
@@ -253,7 +253,7 @@ class ComprehensiveAncestorsReport (Report.Report):
             if len (people):
                 if self.pgbrk:
                     self.doc.page_break()
-                self.doc.start_paragraph ("AR-Heading")
+
                 families = pfamilies
                 families.extend (mfamilies)
                 for self.gp in [families[0].getFather (),
@@ -261,19 +261,24 @@ class ComprehensiveAncestorsReport (Report.Report):
                     if self.gp:
                         break
 
-                relstring = self.get_grandparents_string (self.start,
-                                                                  self.gp)[0]
-                if thisgen == 2:
-                    heading = _("%(name)s's %(parents)s") % \
-                              { 'name': self.first_name_or_nick (self.start),
-                                'parents': relstring }
-                else:
-                    heading = _("%(name)s's paternal %(grandparents)s") % \
-                              { 'name': self.first_name_or_nick (self.start),
-                                'grandparents': relstring }
+                if paternal_known:
+                    self.doc.start_paragraph ("AR-Heading")
+                    relstring = self.get_grandparents_string (self.start,
+                                                              self.gp)[0]
+                    if thisgen == 2:
+                        heading = _("%(name)s's %(parents)s") % \
+                                  { 'name':
+                                    self.first_name_or_nick (self.start),
+                                    'parents': relstring }
+                    else:
+                        heading = _("%(name)s's paternal %(grandparents)s") % \
+                                  { 'name':
+                                    self.first_name_or_nick (self.start),
+                                    'grandparents': relstring }
+
+                    self.doc.write_text (heading)
+                    self.doc.end_paragraph ()
 
-                self.doc.write_text (heading)
-                self.doc.end_paragraph ()
                 self.write_paragraphs (people)
 
                 next_pfamilies = []
@@ -634,6 +639,10 @@ class ComprehensiveAncestorsReport (Report.Report):
 	    	nick = nick[:-1]
             name += ' ("%s")' % nick
 
+        spfx = primary.getSurnamePrefix ()
+        if spfx:
+            name += ' '+ spfx
+
         if last.replace ('?', '') == '':
             if first_replaced == '':
                 name += _(' (unknown)')
@@ -685,14 +694,15 @@ class ComprehensiveAncestorsReport (Report.Report):
 
                         count += 1
 
-                marriage = family.getMarriage ()
-                if marriage:
+                relationship = family.getRelationship ()
+                if relationship == "Married":
+                    marriage = family.getMarriage ()
                     if not first_rel:
                         if gender == RelLib.Person.female:
-                            ret += _('  She later married %(name)s') % \
+                            ret += _('  She also married %(name)s') % \
                                    {'name': self.person_name (spouse)}
                         else:
-                            ret += _('  He later married %(name)s') % \
+                            ret += _('  He also married %(name)s') % \
                                    {'name': self.person_name (spouse)}
 
                     elif (listing_children or
@@ -705,14 +715,15 @@ class ComprehensiveAncestorsReport (Report.Report):
                             ret += _('  He married %(name)s') % \
                                    {'name': self.person_name (spouse)}
 
-                    ret += self.event_info (marriage)
+                    if marriage:
+                        ret += self.event_info (marriage)
                 else: # Not a marriage
                     if not first_rel:
                         if gender == RelLib.Person.female:
-                            ret += _('  She later had a relationship with %(name)s') % \
+                            ret += _('  She also had a relationship with %(name)s') % \
                                    {'name': self.person_name (spouse)}
                         else:
-                            ret += _('  He later had a relationship with %(name)s') % \
+                            ret += _('  He also had a relationship with %(name)s') % \
                                    {'name': self.person_name (spouse)}
                     else:
                         if gender == RelLib.Person.female:
@@ -722,7 +733,9 @@ class ComprehensiveAncestorsReport (Report.Report):
                             ret += _('  He had a relationship with %(name)s') % \
                                    {'name': self.person_name (spouse)}
 
-                ret += children + '.'
+                ret += children
+                if ret and not ret.endswith ("."):
+                    ret += '.'
 
             first_rel = 0
 
@@ -902,7 +915,7 @@ class ComprehensiveAncestorsReportDialog(Report.TextReportDialog):
 
     def add_user_options (self):
         self.cb_cite = gtk.CheckButton (_("Cite sources"))
-        self.cb_cite.set_active (gtk.TRUE)
+        self.cb_cite.set_active (True)
         self.add_option ('', self.cb_cite)
 
     def parse_report_options_frame (self):
