@@ -1,7 +1,7 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2000-2004 Bruce J. DeGrasse
+# Copyright (C) 2000-2005 Bruce J. DeGrasse
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: DetAncestralReport.py,v 1.27.2.5 2004/03/02 03:35:05 rshura Exp $
+# $Id: DetAncestralReport.py,v 1.27.2.7 2005/01/20 00:41:22 rshura Exp $
 
 "Generate files/Detailed Ancestral Report"
 
@@ -442,51 +442,51 @@ class DetAncestorReport(Report.Report):
         HE/SHE married on FULLDATE.
         HE/SHE married in PLACE.
         """
-        famList= person.getFamilyList()
-        if len(famList) > 0:
-            fam_num= 0
-            endOfSent= ""
-            for fam in famList:
-                fam_num= fam_num + 1
-                spouse= ""
-                t= ""
-                if person.getGender() == RelLib.Person.male:
-                    if fam.getMother() != None:
-                        spouse= fam.getMother().getPrimaryName().getRegularName()
-                    if fam_num == 1:
-                        heshe= _("He")
-                    elif fam_num < len(famList):
-                        heshe= _(",")
-                    else: heshe= _("and he")
+        famList = person.getFamilyList()
+        for fam_num in range(len(famList)):
+            fam = famList[fam_num]
+            spouse = ""
+            t = ""
+            if person.getGender() == RelLib.Person.male:
+                if fam.getMother() != None:
+                    spouse = fam.getMother().getPrimaryName().getRegularName()
+                if fam_num == 0:
+                    heshe= _(" He")
+                elif fam_num < len(famList)-1:
+                    heshe = _(",")
                 else:
-                    if fam_num == 1:
-                        heshe= _("She")
-                    elif fam_num < len(famList):
-                        heshe= _(",")
-                    else: heshe= _("and she")
+                    heshe = _(" and he")
+            else:
+                if fam_num == 0:
+                    heshe = _(" She")
+                elif fam_num < len(famList)-1:
+                    heshe = _(",")
+                else:
+                    heshe = _(" and she")
+                if fam.getFather() != None:
+                    spouse= fam.getFather().getPrimaryName().getRegularName()
 
-                    if fam.getFather() != None:
-                        spouse= fam.getFather().getPrimaryName().getRegularName()
+            relationship = fam.getRelationship()
+            marriage_event = fam.getMarriage()
+            fulldate = ""
+            place = ""
+            if marriage_event != None:
+                if marriage_event.getPlace() != None and \
+                            marriage_event.getPlaceName() != "":
+                    place = marriage_event.getPlaceName()
+                elif rptOptions.blankPlace == reportOptions.Yes:
+                    place = "____________"
 
-                marriage= fam.getMarriage()
-                fulldate= ""
-                place= ""
-                if marriage != None:
-                    if marriage.getPlace() != None and \
-                            marriage.getPlaceName() != "":
-                        place= marriage.getPlaceName()
-                    elif rptOptions.blankPlace == reportOptions.Yes:
-                        place= "____________"
-
-                    date= marriage.getDateObj()
-                    if date != None:
-                        if date.getYearValid():
-                            if date.getDayValid() and date.getMonthValid() and \
+                date = marriage_event.getDateObj()
+                if date != None:
+                    if date.getYearValid():
+                        if date.getDayValid() and date.getMonthValid() and \
                                     rptOptions.fullDate == reportOptions.Yes:
-                                fulldate= date.getDate()
-                            elif rptOptions.blankDate == reportOptions.Yes:
-                                fulldate= "__________"
+                            fulldate = date.getDate()
+                        elif rptOptions.blankDate == reportOptions.Yes:
+                            fulldate = "__________"
 
+            if relationship == "Married":
                 if spouse != "":
                     if fulldate == "" and place == "":
                         t= _("  %s married %s") % (heshe, spouse)
@@ -506,11 +506,16 @@ class DetAncestorReport(Report.Report):
                     elif fulldate != "" and place != "":
                         t= _("  %s married on %s in %s") % \
                                              (heshe, fulldate, place)
+            else: # Not a marriage
+                if spouse != "":
+                    t= _("%s had a relationship with %s") % (heshe, spouse)
+                else:
+                    t= _("%s had a relationship with") % heshe
 
-                if t != "":
-                    self.doc.write_text(t)
-                    endOfSent= "."
-                if fam_num == len(famList): self.doc.write_text(endOfSent)
+            if t != "":
+                self.doc.write_text(t)
+                if fam_num == len(famList)-1:
+                    self.doc.write_text(".")
 
     def write_mate(self, mate, rptOptions):
         """Output birth, death, parentage, marriage and notes information """
@@ -611,10 +616,9 @@ class DetAncestorReport(Report.Report):
             dupPerson= self.write_person(key, rptOpt)
             if dupPerson == 0:		# Is this a duplicate ind record
                 if person.getGender() == RelLib.Person.female and  \
-                         rptOpt.listChildren == reportOptions.Yes and  \
-                         len(person.getFamilyList()) > 0:
-                    family= person.getFamilyList()[0]
-                    self.write_children(family, rptOpt)
+                         rptOpt.listChildren == reportOptions.Yes:
+                    for family in person.getFamilyList():
+                        self.write_children(family, rptOpt)
 
                 #if rptOpt.addImages == reportOptions.Yes:
                 #    self.append_images(person)
@@ -768,11 +772,11 @@ class DetAncestorReportDialog(Report.TextReportDialog):
         self.include_notes_option.set_active(1)
 
         # Replace missing Place with ___________
-        self.place_option = gtk.CheckButton(_("Replace Place with ______"))
+        self.place_option = gtk.CheckButton(_("Replace missing places with ______"))
         self.place_option.set_active(0)
 
         # Replace missing dates with __________
-        self.date_option = gtk.CheckButton(_("Replace Dates with ______"))
+        self.date_option = gtk.CheckButton(_("Replace missing dates with ______"))
         self.date_option.set_active(0)
 
         # Add "Died at the age of NN" in text
@@ -988,11 +992,11 @@ class DetAncestorBareReportDialog(Report.BareReportDialog):
         self.include_notes_option.set_active(self.include_notes)
 
         # Replace missing Place with ___________
-        self.place_option = gtk.CheckButton(_("Replace Place with ______"))
+        self.place_option = gtk.CheckButton(_("Replace missing places with ______"))
         self.place_option.set_active(self.place)
 
         # Replace missing dates with __________
-        self.date_option = gtk.CheckButton(_("Replace Dates with ______"))
+        self.date_option = gtk.CheckButton(_("Replace missing dates with ______"))
         self.date_option.set_active(self.date)
 
         # Add "Died at the age of NN" in text
