@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: DetDescendantReport.py,v 1.26.2.6 2004/03/02 03:35:05 rshura Exp $
+# $Id: DetDescendantReport.py,v 1.26.2.8 2005/01/20 00:41:22 rshura Exp $
 
 "Generate files/Detailed Descendant Report"
 
@@ -446,70 +446,79 @@ class DetDescendantReport(Report.Report):
         HE/SHE married SPOUSE in PLACE.
         HE/SHE married SPOUSE
         """
-        famList= person.getFamilyList()
-        if len(famList) > 0:
-            fam_num= 0
-            for fam in famList:
-                fam_num= fam_num + 1
-                spouse= ""
-                if person.getGender() == RelLib.Person.male:
-                    if fam.getMother() != None:
-                        spouse= fam.getMother().getPrimaryName().getRegularName()
-                    if fam_num == 1:
-                        heshe= _("He")
-                    elif fam_num < len(famList):
-                        heshe= _(",")
-                    else: heshe= _("and he")
+        famList = person.getFamilyList()
+        for fam_num in range(len(famList)):
+            fam = famList[fam_num]
+            spouse = ""
+            t = ""
+            if person.getGender() == RelLib.Person.male:
+                if fam.getMother() != None:
+                    spouse = fam.getMother().getPrimaryName().getRegularName()
+                if fam_num == 0:
+                    heshe = _(" He")
+                elif fam_num < len(famList)-1:
+                    heshe = _(",")
                 else:
-                    if fam_num == 1:
-                        heshe= _("She")
-                    elif fam_num < len(famList):
-                        heshe= _(",")
-                    else: heshe= _("and she")
+                    heshe = _(" and he")
+            else:
+                if fam_num == 0:
+                    heshe = _(" She")
+                elif fam_num < len(famList)-1:
+                    heshe = _(",")
+                else:
+                    heshe = _(" and she")
+                if fam.getFather() != None:
+                    spouse = fam.getFather().getPrimaryName().getRegularName()
 
-                    if fam.getFather() != None:
-                        spouse= fam.getFather().getPrimaryName().getRegularName()
+            relationship = fam.getRelationship()
+            marriage_event = fam.getMarriage()
+            fulldate= ""
+            place= ""
+            if marriage_event != None:
+                if marriage_event.getPlace() != None and \
+                        marriage_event.getPlaceName() != "":
+                    place = marriage_event.getPlaceName()
+                elif rptOptions.blankPlace == reportOptions.Yes:
+                    place = "____________"
 
-                marriage= fam.getMarriage()
-                fulldate= ""
-                place= ""
-                if marriage != None:
-                    if marriage.getPlace() != None and \
-                            marriage.getPlaceName() != "":
-                        place= marriage.getPlaceName()
-                    elif rptOptions.blankPlace == reportOptions.Yes:
-                        place= "____________"
-
-                    date= marriage.getDateObj()
-                    if date != None:
-                        if date.getYearValid():
-                            if date.getDayValid() and date.getMonthValid() and \
-                                    rptOptions.fullDate == reportOptions.Yes:
-                                fulldate= date.getDate()
-                            elif rptOptions.blankDate == reportOptions.Yes:
-                                fulldate= "__________"
+                date = marriage_event.getDateObj()
+                if date != None:
+                    if date.getYearValid():
+                        if date.getDayValid() and date.getMonthValid() and \
+                                rptOptions.fullDate == reportOptions.Yes:
+                            fulldate= date.getDate()
+                        elif rptOptions.blankDate == reportOptions.Yes:
+                            fulldate= "__________"
 
+            if relationship == "Married":
                 if spouse != "":
                     if fulldate == "" and place == "":
-                        t= _("  %s married %s") % (heshe, spouse)
+                        t= _("%s married %s") % (heshe, spouse)
                     elif fulldate == "" and place != "":
-                        t= _("  %s married %s in %s") % (heshe, spouse, place)
+                        t= _("%s married %s in %s") % (heshe, spouse, place)
                     elif fulldate != "" and place == "":
-                        t= _("  %s married %s on %s") % (heshe, spouse, fulldate)
-                    else: t= _("  %s married %s on %s in %s") % \
+                        t= _("%s married %s on %s") % (heshe, spouse, fulldate)
+                    else: t= _("%s married %s on %s in %s") % \
                             (heshe, spouse, fulldate, place)
                 else:
                     if fulldate == "" and place == "":
-                        t= _("  %s married") % heshe
+                        t= _("%s married") % heshe
                     elif fulldate == "" and place != "":
-                        t= _("  %s married in %s") % (heshe, place)
+                        t= _("%s married in %s") % (heshe, place)
                     elif fulldate != "" and place == "":
-                        t= _("  %s married on %s") % (heshe, fulldate)
-                    else: t= _("  %s married on %s in %s") % \
+                        t= _("%s married on %s") % (heshe, fulldate)
+                    else: t= _("%s married on %s in %s") % \
                        (heshe, fulldate, place)
+            else: # Not a marriage
+                if spouse != "":
+                    t= _("%s had a relationship with %s") % (heshe, spouse)
+                else:
+                    t= _("%s had a relationship with") % heshe
 
-                if t != "": self.doc.write_text(t)
-                if fam_num == len(famList): self.doc.write_text(".")
+            if t != "":
+                self.doc.write_text(t)
+                if fam_num == len(famList)-1:
+                    self.doc.write_text(".")
 
     def write_mate(self, person, rptOptions):
         """Output birth, death, parentage, marriage and notes information """
@@ -619,10 +628,9 @@ class DetDescendantReport(Report.Report):
                 self.genIDs[person.getId()]= key
                 dupPerson= self.write_person(key, rptOpt)
                 if dupPerson == 0:		# Is this a duplicate ind record
-                    if rptOpt.listChildren == reportOptions.Yes and  \
-                         len(person.getFamilyList()) > 0:
-                        family= person.getFamilyList()[0]
-                        self.write_children(family, rptOpt)
+                    if rptOpt.listChildren == reportOptions.Yes:
+                        for family in person.getFamilyList():
+                            self.write_children(family, rptOpt)
 
                     #if rptOpt.addImages == reportOptions.Yes:
                     #    self.append_images(person)
@@ -777,11 +785,11 @@ class DetDescendantReportDialog(Report.TextReportDialog):
         self.include_notes_option.set_active(1)
 
         # Replace missing Place with ___________
-        self.place_option = gtk.CheckButton(_("Replace Place with ______"))
+        self.place_option = gtk.CheckButton(_("Replace missing places with ______"))
         self.place_option.set_active(0)
 
         # Replace missing dates with __________
-        self.date_option = gtk.CheckButton(_("Replace Dates with ______"))
+        self.date_option = gtk.CheckButton(_("Replace missing dates with ______"))
         self.date_option.set_active(0)
 
         # Add "Died at the age of NN" in text
@@ -998,11 +1006,11 @@ class DetDescendantBareReportDialog(Report.BareReportDialog):
         self.include_notes_option.set_active(self.include_notes)
 
         # Replace missing Place with ___________
-        self.place_option = gtk.CheckButton(_("Replace Place with ______"))
+        self.place_option = gtk.CheckButton(_("Replace missing places with ______"))
         self.place_option.set_active(self.place)
 
         # Replace missing dates with __________
-        self.date_option = gtk.CheckButton(_("Replace Dates with ______"))
+        self.date_option = gtk.CheckButton(_("Replace missing dates with ______"))
         self.date_option.set_active(self.date)
 
         # Add "Died at the age of NN" in text
