@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: FamilyGroup.py,v 1.20.2.2 2004/02/22 19:09:41 rshura Exp $
+# $Id: FamilyGroup.py,v 1.20.2.4 2005/03/14 02:35:53 rshura Exp $
 
 "Generate files/Family Group Report"
 
@@ -525,14 +525,14 @@ class FamilyGroupBareDialog(Report.BareReportDialog):
                 if self.extra_menu:
                     myMenu = Utils.build_string_optmenu(self.new_spouse_map,None)
                     self.extra_menu.set_menu(myMenu)
-                    self.extra_menu.set_sensitive(gtk.FALSE)
+                    self.extra_menu.set_sensitive(False)
                     self.window.show_all()
                     self.extra_menu = None
 
             new_name = new_person.getPrimaryName().getRegularName()
 	    if new_name:
                 self.person_label.set_text( "<i>%s</i>" % new_name )
-                self.person_label.set_use_markup(gtk.TRUE)
+                self.person_label.set_use_markup(True)
 
             
     def on_cancel(self, obj):
