@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: FilterEditor.py,v 1.22.2.1 2004/03/19 03:23:30 dallingham Exp $
+# $Id: FilterEditor.py,v 1.22.2.2 2005/03/14 02:35:53 rshura Exp $
 
 """Generic Filtering Routines"""
 
@@ -143,7 +143,7 @@ class MyPlaces(gtk.Entry):
 class MyID(gtk.HBox):
     
     def __init__(self,db):
-        gtk.HBox.__init__(self,gtk.FALSE,6)
+        gtk.HBox.__init__(self,False,6)
         self.db = db
 
         self.entry = gtk.Entry()
