@@ -1,7 +1,7 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2000-2004  Donald N. Allingham
+# Copyright (C) 2000-2005  Donald N. Allingham
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: GraphViz.py,v 1.23.2.3 2004/03/19 00:29:04 rshura Exp $
+# $Id: GraphViz.py,v 1.23.2.5 2005/02/23 02:31:13 rshura Exp $
 
 "Generate files/Relationship graph"
 
@@ -28,7 +28,7 @@
 #
 #------------------------------------------------------------------------
 import os
-import string
+from gettext import gettext as _
 
 #------------------------------------------------------------------------
 #
@@ -48,7 +48,6 @@ import BaseDoc
 import GenericFilter
 import Errors
 
-from gettext import gettext as _
 from latin_utf8 import utf8_to_latin
 
 #------------------------------------------------------------------------
@@ -73,6 +72,9 @@ class GraphVizDialog(Report.ReportDialog):
 
         Report.ReportDialog.__init__(self,database,person,self.report_options)
 
+    def get_default_basename(self):
+        return "relationship_graph.dot"
+
     def get_title(self):
         """The window title for this dialog"""
         return "%s - %s - GRAMPS" % (_("Relationship Graph"),
@@ -85,7 +87,7 @@ class GraphVizDialog(Report.ReportDialog):
 
     def get_report_generations(self):
         """Default to 10 generations, no page breaks."""
-        return (10, 0)
+        return (0, 0)
 
     def get_report_filters(self):
         """Set up the list of possible content filters."""
@@ -383,7 +385,7 @@ def dump_person(person_list,file,adoptionsdashed,arrowheadstyle,
         person_dict[p.getId()] = 1
 
     for person in person_list:
-        pid = string.replace(person.getId(),'-','_')
+        pid = person.getId().replace('-','_')
         for family, mrel, frel in person.getParentList():
             father   = family.getFather()
             mother   = family.getMother()
@@ -393,7 +395,7 @@ def dump_person(person_list,file,adoptionsdashed,arrowheadstyle,
                 (father and person_dict.has_key(father.getId()) or
                  mother and person_dict.has_key(mother.getId()))):
                 # Link to the family node.
-                famid = string.replace(family.getId(),'-','_')
+                famid = family.getId().replace('-','_')
                 file.write('p%s -> f%s ['  % (pid, famid))
                 file.write('arrowhead=%s, arrowtail=%s, ' %
                            (arrowheadstyle, arrowtailstyle))
@@ -405,7 +407,7 @@ def dump_person(person_list,file,adoptionsdashed,arrowheadstyle,
             else:
                 # Link to the parents' nodes directly.
                 if father and person_dict.has_key(father.getId()):
-                    fid = string.replace(father.getId(),'-','_')
+                    fid = father.getId().replace('-','_')
                     file.write('p%s -> p%s ['  % (pid, fid))
                     file.write('arrowhead=%s, arrowtail=%s, ' %
                                (arrowheadstyle, arrowtailstyle))
@@ -415,7 +417,7 @@ def dump_person(person_list,file,adoptionsdashed,arrowheadstyle,
                         file.write('style=solid')
                     file.write('];\n')
                 if mother and person_dict.has_key(mother.getId()):
-                    mid = string.replace(mother.getId(),'-','_')
+                    mid = mother.getId().replace('-','_')
                     file.write('p%s -> p%s ['  % (pid, mid))
                     file.write('arrowhead=%s, arrowtail=%s, ' %
                                (arrowheadstyle, arrowtailstyle))
@@ -438,7 +440,7 @@ def dump_index(person_list,file,includedates,includeurl,colorize,
     for person in person_list:
         # Output the person's node.
         label = person.getPrimaryName().getName()
-        id = string.replace(person.getId(),'-','_')
+        id = person.getId().replace('-','_')
         if includedates:
             if person.getBirth().getDateObj().getYearValid():
                 if just_year:
@@ -466,15 +468,15 @@ def dump_index(person_list,file,includedates,includeurl,colorize,
                 file.write('color=deeppink, ')
             else:
                 file.write('color=black, ')
-        if font == _TT_FONT:
-            file.write('fontname="%s", label="%s"];\n' % (font,label))
-        else:
+        if font == _PS_FONT:
             file.write('fontname="%s", label="%s"];\n' % (font,utf8_to_latin(label)))
+        else:
+            file.write('fontname="%s", label="%s"];\n' % (font,label))
         # Output families's nodes.
         if show_families:
             family_list = person.getFamilyList()
             for fam in family_list:
-                fid = string.replace(fam.getId(),'-','_')
+                fid = fam.getId().replace('-','_')
                 if fam not in families_done:
                     families_done.append(fam)
                     file.write('f%s [shape=ellipse, ' % fid)
@@ -495,8 +497,6 @@ def dump_index(person_list,file,includedates,includeurl,colorize,
                            (arrowheadstyle, arrowtailstyle))
                 file.write('style=solid];\n')
 
-
-
 #------------------------------------------------------------------------
 #
 #
@@ -528,4 +528,3 @@ if ver[0] == 2 and ver[1] == 2:
         author_name="Donald N. Allingham",
         author_email="dallingham@users.sourceforge.net"
         )
-
