@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: IndivComplete.py,v 1.30.2.5 2004/10/19 00:45:43 rshura Exp $
+# $Id: IndivComplete.py,v 1.30.2.6 2004/11/13 21:42:17 rshura Exp $
 
 #------------------------------------------------------------------------
 #
@@ -511,7 +511,7 @@ class IndivCompleteDialog(Report.TextReportDialog):
         All user dialog has already been handled and the output file
         opened."""
 
-        act = self.use_srcs.get_active()
+        act = int(self.use_srcs.get_active())
         
         try:
             MyReport = IndivComplete(self.db, self.person, self.target_path,
@@ -615,7 +615,7 @@ class IndivCompleteBareReportDialog(Report.BareReportDialog):
         if self.new_person:
             self.person = self.new_person
         self.filter_num = self.filter_combo.get_history()
-        self.use_srcs = self.use_srcs_checkbox.get_active()
+        self.use_srcs = int(self.use_srcs_checkbox.get_active())
         self.options = ( self.person.getId(), self.filter_num, self.use_srcs )
         self.style_name = self.selected_style.get_name()
 
