@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: Merge.py,v 1.9.2.1 2004/06/09 04:49:19 dallingham Exp $
+# $Id: Merge.py,v 1.9.2.5 2004/08/05 02:00:40 dallingham Exp $
 
 "Database Processing/Merge people"
 
@@ -33,7 +33,7 @@ import soundex
 import GrampsCfg
 import ListModel
 import MergeData
-from gettext import gettext as _ 
+from QuestionDialog import WarningDialog
 
 #-------------------------------------------------------------------------
 #
@@ -42,6 +42,7 @@ from gettext import gettext as _
 #-------------------------------------------------------------------------
 import string
 import os
+from gettext import gettext as _ 
 
 #-------------------------------------------------------------------------
 #
@@ -238,6 +239,8 @@ class Merge:
             p2key = p2.getId()
             if self.dellist.has_key(p2key):
                 p2 = self.dellist[p2key]
+            else:
+                p2 = p2key
             if p1 == p2:
                 continue
             list.append((c,p1,p2))
@@ -258,13 +261,17 @@ class Merge:
         (p1,p2) = self.list.get_object(iter)
         pn1 = self.db.getPerson(p1)
         pn2 = self.db.getPerson(p2)
-        MergeData.MergePeople(self.db,pn1,pn2,self.on_update)
+        MergeData.MergePeople(self.db,pn1,pn2,self.on_update,self.update)
 
     def on_update(self,p1,p2,old_id):
-        self.dellist[p2.getId()] = p1.getId()
+        if p1.getId() == p2.getId():
+            self.dellist[old_id] = p1.getId()
+        else:
+            self.dellist[p2.getId()] = p1.getId()
         for key in self.dellist.keys():
             if self.dellist[key] == p2.getId():
                 self.dellist[key] = p1.getId()
+        self.update(1)
         self.redraw()
         
     def update_and_destroy(self,obj):
