@@ -1,7 +1,7 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2000-2004  Donald N. Allingham
+# Copyright (C) 2000-2005  Donald N. Allingham
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: ReadGedcom.py,v 1.41.2.8 2004/09/11 23:21:30 rshura Exp $
+# $Id: ReadGedcom.py,v 1.41.2.11 2005/01/30 03:25:39 dallingham Exp $
 
 "Import from GEDCOM"
 
@@ -367,14 +367,12 @@ class GedcomParser:
         return self.groups
             
     def barf(self,level):
-        import traceback
         msg = _("Warning: line %d was not understood, so it was ignored.") % self.index
         self.errmsg(msg)
         msg = "\n\t%s\n" % self.text
 
         self.errmsg(msg)
         self.error_count = self.error_count + 1
-#        self.errmsg(string.join(traceback.format_stack()))
         self.ignore_sub_junk(level)
 
     def warn(self,msg):
@@ -872,7 +870,7 @@ class GedcomParser:
                     self.person.addEvent(event)
             elif matches[1] == "SOUR":
                 source_ref = self.handle_source(matches,2)
-                self.person.getPrimaryName().addSourceRef(source_ref)
+                self.person.addSourceRef(source_ref)
             elif matches[1] == "REFN":
                 if intRE.match(matches[2]):
                     try:
@@ -991,7 +989,7 @@ class GedcomParser:
                 photo = RelLib.Photo()
                 photo.setPath(path)
                 photo.setDescription(title)
-                photo.setMimeType(Utils.get_mime_type(path))
+                photo.setMimeType(Utils.get_mime_type(os.path.abspath(path)))
                 self.db.addObject(photo)
                 oref = RelLib.ObjectRef()
                 oref.setReference(photo)
@@ -1029,7 +1027,7 @@ class GedcomParser:
                 photo = RelLib.Photo()
                 photo.setPath(path)
                 photo.setDescription(title)
-                photo.setMimeType(Utils.get_mime_type(path))
+                photo.setMimeType(Utils.get_mime_type(os.path.abspath(path)))
                 self.db.addObject(photo)
                 oref = RelLib.ObjectRef()
                 oref.setReference(photo)
