@@ -1,7 +1,7 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2000-2004  Donald N. Allingham
+# Copyright (C) 2000-2005  Donald N. Allingham
 # Contributions by Lorenzo Cappelletti <lorenzo.cappelletti@email.it>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: RelGraph.py,v 1.3.2.4 2004/08/31 23:07:44 rshura Exp $
+# $Id: RelGraph.py,v 1.3.2.6 2005/02/23 02:31:14 rshura Exp $
 
 "Generate files/Relationship graph"
 
@@ -29,10 +29,9 @@
 #
 #------------------------------------------------------------------------
 import os
-import string
-
 from sets import Set
 from time import asctime
+from gettext import gettext as _
 
 #------------------------------------------------------------------------
 #
@@ -53,7 +52,6 @@ import GenericFilter
 import Errors
 
 from RelLib import Event
-from gettext import gettext as _
 from latin_utf8 import utf8_to_latin
 
 #------------------------------------------------------------------------
@@ -113,7 +111,7 @@ class RelGraphDialog(Report.ReportDialog):
 
     def get_report_generations(self):
         """Default to 10 generations, no page breaks."""
-        return (10, 0)
+        return (0, 0)
 
     def get_report_filters(self):
         """Set up the list of possible content filters."""
@@ -476,7 +474,7 @@ def _writeGraphBox (self):
         individualId = _getIndividualId(individual)
         (color, url) = _getIndividualData(self, individual)
         label = _getIndividualLabel(self, individual)
-        _writeNode(self.File, individualId, label, color, url)
+        _writeNode(self.File, individualId, label, color, url, "", self.FontStyle)
     # Writes out a node for each family
     if self.ShowFamilies:
         self.File.write('\n// Family nodes (box graph)\n')
@@ -488,7 +486,7 @@ def _writeGraphBox (self):
                     familyNodes.add(family)
                     familyId = _getFamilyId(family)
                     label = _getFamilyLabel(self, family)
-                    _writeNode(self.File, familyId, label)
+                    _writeNode(self.File, familyId, label,"","","",self.FontStyle)
     # Links each individual to their parents/family
     self.File.write('\n// Individual edges\n')
     _writeEdge(self.File, style="solid", arrowHead=self.ArrowHeadStyle,
@@ -600,7 +598,7 @@ def _writeGraphRecord (self):
     for familyId, family in familyNodes.items():
         (color, url) = _getIndividualData(self, familyNodes[familyId][0])
         label = _getFamilyRecordLabel(self, familyNodes[familyId])
-        _writeNode(self.File, familyId, label, color, url)
+        _writeNode(self.File, familyId, label, color, url, "", self.FontStyle)
     # Links individual's record to their parents' record
     # The arrow goes from the individual port of a family record
     # to the parent port of the parent's family record.
@@ -699,19 +697,20 @@ def _getIndividualData (self, individual):
 #------------------------------------------------------------------------
 def _getEventLabel (self, event):
     """Returns a formatted string of event data suitable for a label"""
+    label = ''
     if self.IncludeDates and event:
         dateObj = event.getDateObj()
         if dateObj.getYearValid():
             if self.JustYear:
-                return "%i" % dateObj.getYear()
+                label = "%i" % dateObj.getYear()
             else:
-                return dateObj.getDate()
+                label =  dateObj.getDate()
         elif self.PlaceCause:
             if event.getPlaceName():
-                return event.getPlaceName()
+                label = event.getPlaceName()
             else:
-                return event.getCause()
-    return ''
+                label = event.getCause()
+    return label
 
 #------------------------------------------------------------------------
 #
@@ -749,7 +748,7 @@ def _getIndividualLabel (self, individual, marriageEvent=None, family=None):
     label = label + name
     # Birth and death
     if self.IncludeDates and (birth or death):
-        label = label + "\\n%s - %s" % (birth, death)
+        label = label + '\\n%s - %s' % (birth, death)
     return label
 
 #------------------------------------------------------------------------
@@ -779,11 +778,10 @@ def _getFamilyId (family):
 #------------------------------------------------------------------------
 def _getFamilyLabel (self, family):
     """Returns a formatted string of family data suitable for a label"""
-    marriage = _getEventLabel(self, family.getMarriage())
+    label = _getEventLabel(self, family.getMarriage())
     if self.IncludeId:
-        return "%s\\n%s" % (family.getId(), marriage)
-    else:
-        return marriage
+        label = "%s\\n%s" % (family.getId(), label)
+    return label
 
 #------------------------------------------------------------------------
 #
@@ -808,11 +806,11 @@ def _getFamilyRecordLabel (self, record):
                     break
             label = _getIndividualLabel(self, individual, marriageEvent,
                                         individualFamily)
-        label = string.replace(label, "|", r"\|")
-        label = string.replace(label, "<", r"\<")
-        label = string.replace(label, ">", r"\>")
+        label = label.replace("|", r"\|")
+        label = label.replace("<", r"\<")
+        label = label.replace( ">", r"\>")
         labels.append("<%s>%s" % (individualId, label))
-    return string.join(labels, "|")
+    return "|".join(labels)
 
 #------------------------------------------------------------------------
 #
@@ -822,18 +820,16 @@ def _getFamilyRecordLabel (self, record):
 def _writeNode (file, node="node", label="", color="", url="", shape="",
                fontname=""):
     """Writes out an individual node"""
-    file.write('%s [' % node)
+    file.write('%s [' % node.replace('-','_'))
     if label:
-        if fontname == _TT_FONT:
-            file.write('label="%s" ' %
-                   string.replace(label, '"', r'\"'))
+        if fontname == _PS_FONT:
+            file.write('label="%s" ' % utf8_to_latin(label.replace('"',r'\"')))
         else:
-            file.write('label="%s" ' %
-                   utf8_to_latin(string.replace(label, '"', r'\"')))
+            file.write('label="%s" ' % label.replace('"',r'\"'))
     if color:
         file.write('color=%s ' % color)
     if url:
-        file.write('URL="%s" ' % string.replace(url, '"', r'\"'))
+        file.write('URL="%s" ' % url.replace('"', r'\"'))
     if shape:
         file.write('shape=%s ' % shape)
     if fontname:
@@ -857,7 +853,7 @@ def _writeEdge (file, nodeFrom="", nodeTo="", style="",
             to = nodeTo + ":" + portTo
         else:
             to = nodeTo
-        file.write('%s -> %s [' % (frm, to))
+        file.write('%s -> %s [' % (frm.replace('-','_'), to.replace('-','_')))
     else:
         file.write('edge [')  # default edge
     if style:
