@@ -17,7 +17,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: SimpleBookTitle.py,v 1.20 2004/02/01 00:44:31 rshura Exp $
+# $Id: SimpleBookTitle.py,v 1.20.2.2 2005/03/14 02:35:53 rshura Exp $
 
 #------------------------------------------------------------------------
 #
@@ -258,8 +258,8 @@ class SimpleBookTitleDialog(Report.BareReportDialog):
             else:
                 icon_image = gtk.gdk.pixbuf_new_from_file(Utils.find_icon(the_type))
                 self.preview.set_from_pixbuf(icon_image)
-            self.remove_obj_button.set_sensitive(gtk.TRUE)
-            self.size_menu.set_sensitive(gtk.TRUE)
+            self.remove_obj_button.set_sensitive(True)
+            self.size_menu.set_sensitive(True)
 
         self.new_person = None
 
@@ -308,7 +308,7 @@ class SimpleBookTitleDialog(Report.BareReportDialog):
         self.obj_title = gtk.Label('')
         self.remove_obj_button = gtk.Button(None,gtk.STOCK_REMOVE)
         self.remove_obj_button.connect('clicked',self.remove_obj)
-        self.remove_obj_button.set_sensitive(gtk.FALSE)
+        self.remove_obj_button.set_sensitive(False)
         preview_table = gtk.Table(2,1)
         preview_table.set_row_spacings(10)
         preview_table.attach(frame,0,1,1,2,gtk.SHRINK|gtk.FILL,gtk.SHRINK|gtk.FILL)
@@ -329,7 +329,7 @@ class SimpleBookTitleDialog(Report.BareReportDialog):
 
         self.size_menu = gtk.OptionMenu()
         make_size_menu(self.size_menu)
-        self.size_menu.set_sensitive(gtk.FALSE)
+        self.size_menu.set_sensitive(False)
 
         self.add_frame_option(_('Image'),_('Preview'),preview_table)
         self.add_frame_option(_('Image'),_('Select'),select_table)
@@ -354,8 +354,8 @@ class SimpleBookTitleDialog(Report.BareReportDialog):
         self.object_id = ""
         self.obj_title.set_text('')
         self.preview.set_from_pixbuf(None)
-        self.remove_obj_button.set_sensitive(gtk.FALSE)
-        self.size_menu.set_sensitive(gtk.FALSE)
+        self.remove_obj_button.set_sensitive(False)
+        self.size_menu.set_sensitive(False)
 
     def select_obj(self, obj):
         s_o = SelectObject.SelectObject(self.db,_("Select an Object"))
@@ -374,8 +374,8 @@ class SimpleBookTitleDialog(Report.BareReportDialog):
         else:
             icon_image = gtk.gdk.pixbuf_new_from_file(Utils.find_icon(the_type))
             self.preview.set_from_pixbuf(icon_image)
-        self.remove_obj_button.set_sensitive(gtk.TRUE)
-        self.size_menu.set_sensitive(gtk.TRUE)
+        self.remove_obj_button.set_sensitive(True)
+        self.size_menu.set_sensitive(True)
 
     def select_file(self, obj):
         a_o = AddMedia.AddMediaObject(self.db)
@@ -394,8 +394,8 @@ class SimpleBookTitleDialog(Report.BareReportDialog):
         else:
             icon_image = gtk.gdk.pixbuf_new_from_file(Utils.find_icon(the_type))
             self.preview.set_from_pixbuf(icon_image)
-        self.remove_obj_button.set_sensitive(gtk.TRUE)
-        self.size_menu.set_sensitive(gtk.TRUE)
+        self.remove_obj_button.set_sensitive(True)
+        self.size_menu.set_sensitive(True)
 
     def on_ok_clicked(self, obj):
         """The user is satisfied with the dialog choices. Parse all options
