@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: TimeLine.py,v 1.18.2.3 2004/08/12 02:02:39 rshura Exp $
+# $Id: TimeLine.py,v 1.18.2.4 2004/11/28 03:02:50 dallingham Exp $
 
 """
 Timeline report
@@ -157,6 +157,13 @@ class TimeLine:
 
         (low,high) = self.find_year_range()
 
+        if low == high:
+            if self.standalone:
+                self.d.close()
+            ErrorDialog(_("Report could not be created"),
+                        _("The range of dates chosen was not valid"))
+            return
+
         st_size = self.name_size()
 
         font = self.d.style_list['TLG-Name'].get_font()
