@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: WebPage.py,v 1.30.2.14 2004/08/06 21:43:37 rshura Exp $
+# $Id: WebPage.py,v 1.30.2.15 2005/03/12 17:28:01 rshura Exp $
 
 "Web Site/Generate Web Site"
 
@@ -1060,7 +1060,7 @@ class WebReportDialog(Report.ReportDialog):
         self.depth.set_digits(0)
         self.depth.set_increments(1,2)
         self.depth.set_range(1,10)
-        self.depth.set_numeric(gtk.TRUE)
+        self.depth.set_numeric(True)
         self.depth.set_value(3)
 
         self.use_link = gtk.CheckButton(lnk_msg)
@@ -1091,7 +1091,7 @@ class WebReportDialog(Report.ReportDialog):
         self.use_n_cols.set_digits(0)
         self.use_n_cols.set_increments(1,2)
         self.use_n_cols.set_range(1,5)
-        self.use_n_cols.set_numeric(gtk.TRUE)
+        self.use_n_cols.set_numeric(True)
         self.ind_template = gtk.Combo()
         template_list = [ Report._default_template ]
         tlist = Report._template_map.keys()
